@@ -102,6 +102,7 @@ clear_cpu(int fd_data, int cpu, const char *data_filename)
 {
 	char text[400];
 	int l;
+
 	snprintf(text, sizeof(text), "clear %d\n", cpu);
 	l = strlen(text);
 	if (write(fd_data, text, l) != l) {
@@ -276,7 +277,13 @@ talk_to_sal (const char *type, const char *directory)
 			cpu,
 			type,
 			suffix);
-		if (!(freopen(filename, "w", stdout) && freopen(filename, "w", stderr))) {
+		fclose(stdout);
+		if (!(stdout = fopen(filename, "w"))) {
+			perror(filename);
+			goto out;
+		}
+		fclose(stderr);
+		if (!((stderr = fopen(filename, "w")))) {
 			perror(filename);
 			goto out;
 		}
